# SETPROJ

Have project setup **instantly** on _cli_.

As programmer and terminal(and terminal tools) lover, I wanted something which will ease the redundant task of setting up project for the languages I use. The following project helps in achieving just that.

Let's see how it is done. Here's a project creation demo for `java` language:

![proj-creation-c](https://github.com/coolabhays/project-setup/raw/master/sshots/c-mkproj.png)

<hr>

![proj-creation-servlet](https://github.com/coolabhays/project-setup/raw/master/sshots/servlet-mkproj.png)

<br>

### Supported Languages:

Currenlty, following languages(and tool/s) are supported in this project for _project creation_:

* C
* C++
* Java
* Python
* Web Designing(html,css,js)
* Java-Servlet

<br>


### What it does:

It's an interactive project which puts all the necessary files/folders in place as user tells and fills up some things already which is to be filled everytime,

Here's an example of fillup for `Java-Servlet`:

![java-servlet-fillup](https://github.com/coolabhays/project-setup/raw/master/sshots/servlet-fillup.png)


And here's the directory hierarchy for all the supported languages:

* **C**:

![C-dir-struct](https://github.com/coolabhays/project-setup/raw/master/sshots/structure-cproj.png)

<hr>


* **C++**:

![c++-dir-struct](https://github.com/coolabhays/project-setup/raw/master/sshots/structure-cppproj.png)

<hr>


* **Java**:

![java-dir-struct](https://github.com/coolabhays/project-setup/raw/master/sshots/structure-javaproj.png)

<hr>

* **Python**:

![python-dir-struct](https://github.com/coolabhays/project-setup/raw/master/sshots/structure-pyproj.png)

<hr>

* **Web Designing**:

![webd-dir-struct](https://github.com/coolabhays/project-setup/raw/master/sshots/structure-webdproj.png)

<hr>

* **Java Servlet**:

![servlet-dir-struct](https://github.com/coolabhays/project-setup/raw/master/sshots/structure-servlet.png)

<br>
```
Note: This project is still in development stage
```
